==> qunit-0.2.10.tgz: package/lib/log.js <==
var util = require('util'),
    Table = require('cli-table');

var data;

data = {
    assertions: [],
    tests: [],
    summaries: []
};

exports.assertion = function(d) {
    if (d) {
        data.assertions.push(d);
    }

    return data.assertions;
};

exports.test = function(d) {
    if (d) {
        data.tests.push(d);
    }

    return data.tests;
};

exports.summary = function(d) {
    if (d) {
        data.summaries.push(d);
    }

    return data.summaries;
};

var print = {};

print.assertions = function() {
    var table,
        currentModule, module,
        currentTest, test;

    table = new Table({
        head: ['Module', 'Test', 'Assertion', 'Result'],
        colWidths: [40, 40, 40, 8]
    });

    data.assertions.forEach(function(data) {
        // just easier to read the table
        if (data.module === currentModule) {
            module = '';
        } else {
            module = currentModule = data.module;
        }

        // just easier to read the table
        if (data.test === currentTest) {
            test = '';
        } else {
            test = currentTest = data.test;
        }

        table.push([module, test, data.message, data.result ? 'ok' : 'fail']);
    });

    util.print('\nAssertions:\n' + table.toString() + '\n');
}

print.tests = function() {
    var table,
        currentModule, module;

    table = new Table({
        head: ['Module', 'Test', 'Failed', 'Passed', 'Total'],
        colWidths: [40, 40, 8, 8, 8]
    });

    data.tests.forEach(function(data) {
        // just easier to read the table
        if (data.module === currentModule) {
            module = '';
        } else {
            module = currentModule = data.module;
        }

        table.push([module, data.name, data.failed, data.passed, data.total]);
    });

    util.print('\Tests:\n' + table.toString() + '\n');
}

print.summary = function() {
    var table, fileColWidth = 50;

    table = new Table({
        head: ['File', 'Failed', 'Passed', 'Total', 'Runtime'],
        colWidths: [fileColWidth + 2, 10, 10, 10, 10]
    });

    data.summaries.forEach(function(data) {
        var code = data.code;

        // truncate file name
        if (code.length > fileColWidth) {
            code = '...' + code.slice(code.length - fileColWidth + 3);
        }

        table.push([code, data.failed, data.passed, data.total, data.runtime]);
    });

    util.print('\Summary:\n' + table.toString() + '\n');
}

print.globalSummary = function() {
    var table,
        data = exports.stats();

    table = new Table({
        head: ['Files', 'Tests', 'Assertions', 'Failed', 'Passed', 'Runtime'],
        colWidths: [12, 12, 12, 12, 12, 12]
    });

    table.push([data.files, data.tests, data.assertions, data.failed,
        data.passed, data.runtime]);

    util.print('\Global summary:\n' + table.toString() + '\n');
};

/**
 * Get global tests stats in unified format
 */
exports.stats = function() {
    var stats = {
            files: 0,
            assertions: 0,
            failed: 0,
            passed: 0,
            runtime: 0
        };

    data.summaries.forEach(function(file) {
        stats.files++;
        stats.assertions += file.total;
        stats.failed += file.failed;
        stats.passed += file.passed;
        stats.runtime += file.runtime;
    });

    stats.tests = data.tests.length;

    return stats;
};

/**
 * Reset global stats data
 */
exports.reset = function() {
    data = {
        assertions: [],
        tests: [],
        summaries: []
    };
};

/**
 * Print stats table to the stdout
 * @param {string} name of the table.
 */
exports.print = function(name) {
    if (print[name]) {
        print[name]();
    } else {
        throw new Error('bad stats name: ' + name );
    }
};

==> qunit-0.3.0.tgz: package/lib/log.js <==
var Table = require('cli-table');

var data,
    log = console.log;

data = {
    assertions: [],
    tests: [],
    summaries: []
};

exports.assertion = function(d) {
    if (d) {
        data.assertions.push(d);
    }

    return data.assertions;
};

exports.test = function(d) {
    if (d) {
        data.tests.push(d);
    }

    return data.tests;
};

exports.summary = function(d) {
    if (d) {
        data.summaries.push(d);
    }

    return data.summaries;
};

/**
 * Get global tests stats in unified format
 */
exports.stats = function() {
    var stats = {
            files: 0,
            assertions: 0,
            failed: 0,
            passed: 0,
            runtime: 0
        };

    data.summaries.forEach(function(file) {
        stats.files++;
        stats.assertions += file.total;
        stats.failed += file.failed;
        stats.passed += file.passed;
        stats.runtime += file.runtime;
    });

    stats.tests = data.tests.length;

    return stats;
};

/**
 * Reset global stats data
 */
exports.reset = function() {
    data = {
        assertions: [],
        tests: [],
        summaries: []
    };
};

var print = {};

print.assertions = function() {
    var table,
        currentModule, module,
        currentTest, test;

    table = new Table({
        head: ['Module', 'Test', 'Assertion', 'Result'],
        colWidths: [40, 40, 40, 8]
    });

    data.assertions.forEach(function(data) {
        // just easier to read the table
        if (data.module === currentModule) {
            module = '';
        } else {
            module = currentModule = data.module;
        }

        // just easier to read the table
        if (data.test === currentTest) {
            test = '';
        } else {
            test = currentTest = data.test;
        }

        table.push([module, test, data.message, data.result ? 'ok' : 'fail']);
    });

    log('Assertions:\n' + table.toString());
};

print.errors = function() {
    var currentModule, module,
        currentTest, test;

    log('\nErrors:\n');
    data.assertions.forEach(function(data) {

        // only log a failed test
        if (data.result) {
            return;
        }
        log('Module: ' + data.module + ' Test: ' + data.test);
        log('Actual value:');
        log(data.actual);
        log('Expected value:');
        log(data.expected);
    });
};

print.tests = function() {
    var table,
        currentModule, module;

    table = new Table({
        head: ['Module', 'Test', 'Failed', 'Passed', 'Total'],
        colWidths: [40, 40, 8, 8, 8]
    });

    data.tests.forEach(function(data) {
        // just easier to read the table
        if (data.module === currentModule) {
            module = '';
        } else {
            module = currentModule = data.module;
        }

        table.push([module, data.name, data.failed, data.passed, data.total]);
    });

    log('\Tests:\n' + table.toString());
};

print.summary = function() {
    var table, fileColWidth = 50;

    table = new Table({
        head: ['File', 'Failed', 'Passed', 'Total', 'Runtime'],
        colWidths: [fileColWidth + 2, 10, 10, 10, 10]
    });

    data.summaries.forEach(function(data) {
        var code = data.code;

        // truncate file name
        if (code.length > fileColWidth) {
            code = '...' + code.slice(code.length - fileColWidth + 3);
        }

        table.push([code, data.failed, data.passed, data.total, data.runtime]);
    });

    log('\Summary:\n' + table.toString());
};

print.globalSummary = function() {
    var table,
        data = exports.stats();

    table = new Table({
        head: ['Files', 'Tests', 'Assertions', 'Failed', 'Passed', 'Runtime'],
        colWidths: [12, 12, 12, 12, 12, 12]
    });

    table.push([data.files, data.tests, data.assertions, data.failed,
        data.passed, data.runtime]);

    log('\Global summary:\n' + table.toString());
};

/**
 * Print stats table to the stdout
 * @param {String} name of the table.
 * @api public
 */
exports.print = function(name) {
    if (print[name]) {
        print[name]();
    } else {
        throw new Error('bad stats name: ' + name );
    }
};
